import type { KeyPairSigner } from './KeyPairSigner';
import type { JsonArray, LdKeyPair } from '@credo-ts/core';
import type { Bls12381G2KeyPair } from '@mattrglobal/bls12381-key-pair';
/**
 * Options for constructing a signature suite
 */
export interface SignatureSuiteOptions {
    /**
     * An optional signer interface for handling the sign operation
     */
    readonly signer?: KeyPairSigner;
    /**
     * The key pair used to generate the proof
     */
    readonly key?: Bls12381G2KeyPair;
    /**
     * A key id URL to the paired public key used for verifying the proof
     */
    readonly verificationMethod?: string;
    /**
     * The `created` date to report in generated proofs
     */
    readonly date?: string | Date;
    /**
     * Indicates whether to use the native implementation
     * of RDF Dataset Normalization
     */
    readonly useNativeCanonize?: boolean;
    /**
     * Additional proof elements
     */
    readonly proof?: JsonArray;
    /**
     * Linked Data Key class implementation
     */
    readonly LDKeyClass?: LdKeyPair;
}
